@@ -15,7 +15,7 @@ use Prima::StdBitmap;
 my $testing = 0;
 my $bmImageFile = Prima::Utils::find_image( '', "App::PLab::ImageApp.gif");
 
-sub icon  { return Prima::StdBitmap::load_std_bmp( $_[0], 1, 0, $bmImageFile); }
-sub image { return Prima::StdBitmap::load_std_bmp( $_[0], 0, 0, $bmImageFile); }
+sub icon  { return Prima::StdBitmap::load_std_bmp( index => $_[0], icon => 1, copy => 0, file => $bmImageFile); }
+sub image { return Prima::StdBitmap::load_std_bmp( index => $_[0], icon => 0, copy => 0, file => $bmImageFile); }
 
 1;
